@@ -27,7 +27,10 @@ class TablibAdmin(admin.ModelAdmin):
         super(TablibAdmin, self).__init__(*args, **kwargs)
 
     def get_urls(self):
-        from django.conf.urls.defaults import patterns, url
+        try:
+            from django.conf.urls import patterns, url
+        except ImportError:  # Django <1.4
+            from django.conf.urls.defaults import patterns, url
 
         def wrap(view):
             def wrapper(*args, **kwargs):
